==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/action.acp_acl_delete.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */
  if ( !defined('__XF_INCLUDE') )
  die('File "'.basename(__FILE__).'" cannot be executed directly!');

/**
* @package lbfrontend
*/
class XFAction_acp_acl_delete extends XFAction {
const USE_TAN = true;
protected $success = false;
protected $error = '';
protected $gpc = array();
protected $markgpc = array();
public $version = 0x01;

  /**
  * @param string $a select handler
  * @param array $b input data for asynchronous request
  * @return mixed
  * @since 1.0.0
  */
  public function init($a,$b){
  XFUI::load_lang_res('','acp');
  return $this->$a($b);
  }

  /**
  * @return true
  * @since 1.0.0
  */
  protected function regular(){
  XFUI::html_redirect(-1,XF::link('acp_overview'));
  return true;
  }

  /**
  * @return true
  * @since 1.0.0
  */
  protected function ajax($input){
  $id = XF::sanitize_var(XF::ifset($input,'id',0),'int');
  $this->gpc = array('id'=>$id);
  return true;
  }

  /**
  * delete an access control entry
  * @return boolean
  * @since 1.0.0
  */
  public function execute(){
    try {
      if ( empty($this->error) ){
        if ( !XF::sql_transaction('begin',array('acl'=>'w')) )
        throw new XFE('unable to begin database transaction');
      $sacl = XF::sql_query("SELECT a_action FROM ".XF::tbl('acl')." WHERE a_id = :id",array(
      'id'=>array($this->gpc['id'],'int')),__METHOD__,__LINE__);
        if ( $sacl->rowCount() !== 1 )
        throw new XFE('ACE "'.$this->gpc['id'].'" could not be found in database');
      $acldata = $sacl->fetchObject();
      $sacl->closeCursor();
      $d = XF::sql_query("DELETE FROM ".XF::tbl('acl')." WHERE a_id = :id AND a_use_group = false",array(
      'id'=>array($this->gpc['id'],'int')),__METHOD__,__LINE__);
        if ( !$d )
        throw new XFE('ACE "'.$this->gpc['id'].'" could not be deleted');
      XFCache::purge('acl',crc32($acldata->a_action));
      XF::logger('info','id',$this->gpc['id'],'action',$acldata->a_action);
      XF::sql_transaction('commit');
      $this->success = true;
      }
    } catch ( XFE $E ){ $E->handle(); if ( $E->check_abort() ) return false; }
  return true;
  }

}

  function xfaf_acp_acl_delete($input){
  $a = new XFAction_acp_acl_delete();
  $a->init('ajax',$input);
    if ( !xfaf_process_data($a->get_GPC(),$a->get_mark_GPC()) )
    return false;
  $b = $a->get_GPC();
  $a->execute();
    if ( $a->get_success() ){
    XFUI::$ajax_response->assign('f_ace_'.intval($b['id']),'style.display','none');
    return xfaf_success('','{:delete_ace_successful}');
    }
    else
    return xfaf_failure($a->get_error());
  }

?>

==> larus_board-0.9.18.zip: larus_board-0.9.18/lb_private/action.acp_acl_delete.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board".
 *
 * "Larus Board" is free software: you can redistribute it and/or modify
 * it under the terms of the modified BSD license.
 *
 * "Larus Board" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * You should have received a copy of the modified BSD License
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.BSD>.
 */
  if ( !defined('__XF_INCLUDE') )
  die('File "'.basename(__FILE__).'" cannot be executed directly!');

/**
* @package lbfrontend
*/
class XFAction_acp_acl_delete extends XFAction {
const USE_TAN = true;
protected $success = false;
protected $error = '';
protected $gpc = array();
protected $markgpc = array();
public $version = 0x01;

  /**
  * @param string $a select handler
  * @param array $b input data for asynchronous request
  * @return mixed
  * @since 1.0.0
  */
  public function init($a,$b){
  XFUI::load_lang_res('','acp');
  return $this->$a($b);
  }

  /**
  * @return true
  * @since 1.0.0
  */
  protected function regular(){
  XFUI::html_redirect(-1,XF::link('acp_overview'));
  return true;
  }

  /**
  * @return true
  * @since 1.0.0
  */
  protected function ajax($input){
  $id = XF::sanitize_var(XF::ifset($input,'id',0),'int');
  $this->gpc = array('id'=>$id);
  return true;
  }

  /**
  * delete an access control entry
  * @return boolean
  * @since 1.0.0
  */
  public function execute(){
    try {
      if ( empty($this->error) ){
        if ( !XF::sql_transaction('begin',array('acl'=>'w')) )
        throw new XFE('unable to begin database transaction');
      $sacl = XF::sql_query("SELECT a_action FROM ".XF::tbl('acl')." WHERE a_id = :id",array(
      'id'=>array($this->gpc['id'],'int')),__METHOD__,__LINE__);
        if ( $sacl->rowCount() !== 1 )
        throw new XFE('ACE "'.$this->gpc['id'].'" could not be found in database');
      $acldata = $sacl->fetchObject();
      $sacl->closeCursor();
      $d = XF::sql_query("DELETE FROM ".XF::tbl('acl')." WHERE a_id = :id AND a_use_group = false",array(
      'id'=>array($this->gpc['id'],'int')),__METHOD__,__LINE__);
        if ( !$d )
        throw new XFE('ACE "'.$this->gpc['id'].'" could not be deleted');
      XFCache::purge('acl',crc32($acldata->a_action));
      XF::logger('info','id',$this->gpc['id'],'action',$acldata->a_action);
      XF::sql_transaction('commit');
      $this->success = true;
      }
    } catch ( XFE $E ){ $E->handle(); if ( $E->check_abort() ) return false; }
  return true;
  }

}

  function xfaf_acp_acl_delete($input){
  $a = new XFAction_acp_acl_delete();
  $a->init('ajax',$input);
    if ( !xfaf_process_data($a->get_GPC(),$a->get_mark_GPC()) )
    return false;
  $b = $a->get_GPC();
  $a->execute();
    if ( $a->get_success() ){
    XFUI::$ajax_response->script('xf_visibility(\'f_ace_'.intval($b['id']).'\',\'none\');');
    return xfaf_success('','{:delete_ace_successful}');
    }
    else
    return xfaf_failure($a->get_error());
  }

?>
